@@ -182,6 +182,8 @@ bjb_application_init (BjbApplication *self)
 {
   self->settings = bjb_settings_new ();
   g_queue_init (&self->files_to_open);
+
+  gtk_window_set_default_icon_name ("org.gnome.bijiben");
 }
 
 
@@ -252,6 +254,7 @@ manager_ready_cb (GObject *source,
 {
   BjbApplication *self = user_data;
   GError *error = NULL;
+  gchar *path, *uri;
 
   self->manager = biji_manager_new_finish (res, &error);
   g_application_release (G_APPLICATION (self));
@@ -263,6 +266,24 @@ manager_ready_cb (GObject *source,
       return;
     }
 
+  /* Automatic imports on startup */
+  if (self->first_run == TRUE)
+    {
+      path = g_build_filename (g_get_user_data_dir (), "tomboy", NULL);
+      uri = g_filename_to_uri (path, NULL, NULL);
+      if (g_file_test (path, G_FILE_TEST_EXISTS))
+        bijiben_import_notes (self, uri);
+      g_free (path);
+      g_free (uri);
+
+      path = g_build_filename (g_get_user_data_dir (), "gnote", NULL);
+      uri = g_filename_to_uri (path, NULL, NULL);
+      if (g_file_test (path, G_FILE_TEST_EXISTS))
+        bijiben_import_notes (self, uri);
+      g_free (path);
+      g_free (uri);
+    }
+
   bijiben_new_window_internal (self, NULL);
 }
 
@@ -273,7 +294,6 @@ bijiben_startup (GApplication *application)
   gchar          *storage_path, *default_color;
   GFile          *storage;
   GError         *error;
-  gchar          *path, *uri;
   GdkRGBA         color = {0,0,0,0};
 
 
@@ -311,22 +331,6 @@ bijiben_startup (GApplication *application)
   g_application_hold (application);
   biji_manager_new_async (storage, &color, manager_ready_cb, self);
 
-  /* Automatic imports on startup */
-  if (self->first_run == TRUE)
-  {
-    path = g_build_filename (g_get_user_data_dir (), "tomboy", NULL);
-    uri = g_filename_to_uri (path, NULL, NULL);
-    bijiben_import_notes (self, uri);
-    g_free (path);
-    g_free (uri);
-
-    path = g_build_filename (g_get_user_data_dir (), "gnote", NULL);
-    uri = g_filename_to_uri (path, NULL, NULL);
-    bijiben_import_notes (self, uri);
-    g_free (path);
-    g_free (uri);
-  }
-
   g_free (default_color);
   g_free (storage_path);
   g_object_unref (storage);
